## opsmodel

```
A python library for creating openseespy models.
```

---

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install opsmodel.

```
pip install opsmodel
```
---
## Usage

Import opsmodel in your Python code(openseespy project) like this:

```python
import opsmodel.model as omd
```


---
## Support
- [Email](mailto:ok.programss@gmail.com)

- [Telegram Channel](https://t.me/OKprograms)

- [Instagram](https://www.instagram.com/opensees_apps/?hl=en)

---
## Author
```
Oktai Alizade Arasi
Master of Science in Structural Engineering
```
---
## Documentation

- Download from: 

---
## License
```
OSI Approved : MIT License
```
---